Index: third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
diff --git a/third_party/WebKit/Source/modules/payments/PaymentsValidators.h b/third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
index cf6db8e3c6f4b41f318b324ffca939acc4711c1f..8bef124eefd6bc612c549027816d697c0bff3822 100644 |
--- a/third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
+++ b/third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
@@ -17,10 +17,14 @@ class MODULES_EXPORT PaymentsValidators final { |
public: |
// The most common identifiers are three-letter alphabetic codes as defined by |
// [ISO4217] (for example, "USD" for US Dollars) however any string of at most |
// 2048 characters is considered valid. Returns false if currency |code| is |
// too long (greater than 2048). |
static bool isValidCurrencyCodeFormat(const String& code, |
+ const String& system, |
String* optionalErrorMessage); |
// Returns true if |amount| is a valid currency code as defined in ISO 20022 |
@@ -17,10 +17,14 @@ class MODULES_EXPORT PaymentsValidators final { |
public: |
// The most common identifiers are three-letter alphabetic codes as defined by |
- // [ISO4217] (for example, "USD" for US Dollars) however any string of at most |
- // 2048 characters is considered valid. Returns false if currency |code| is |
- // too long (greater than 2048). |
+ // [ISO4217] (for example, "USD" for US Dollars). |system| is a URL that |
+ // indicates the currency system that the currency identifier belongs to. By |
+ // default, the value is urn:iso:std:iso:4217 indicating that currency is |
+ // defined by [[ISO4217]], however any string of at most 2048 characters is |
+ // considered valid in other currencySystem. Returns false if currency |code| |
+ // is too long (greater than 2048). |
static bool isValidCurrencyCodeFormat(const String& code, |